package
Version:
v1.0.0
Opens a new window with list of versions in this module.
Published: Mar 28, 2023
License: Apache-2.0
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 1
Opens a new window with list of known importers.
Documentation
¶
type GetPayload struct {
ConfigName string `json:"config"`
AnswerFile string `json:"answer_file"`
ReleaseName string `json:"release_name"`
Namespace string `json:"namespace"`
Params map[string]string `json:"params"`
}
type GetServiceIP struct {
ReleaseName string `json:"release_name"`
Namespace string `json:"namespace"`
}
type ImportChartRepo struct {
Repo string `json:"repo"`
RepoName string `json:"repo_name"`
}
type InstallUpgradeRequest struct {
Chart string `json:"chart"`
ReleaseName string `json:"release_name"`
Namespace string `json:"namespace"`
Params map[string]string `json:"params"`
Config map[string]interface{} `json:"config"`
Result string `json:"result"`
}
type NamespaceChartRepo struct {
Namespace string `json:"namespace"`
}
type ServiceDetails struct {
ServiceName string `json:"service_name" yaml:"service_name"`
ServiceType string `json:"service_type" yaml:"service_type"`
IP string `json:"ip" yaml:"ip"`
Port int32 `json:"port" yaml:"port"`
}
type UninstallChartRepo struct {
ReleaseName string `json:"release_name"`
Namespace string `json:"namespace"`
Result string `json:"result"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.